@@ -115,7 +115,30 @@ def set_blocksize(blocksize):
     """
 
     _ext.set_blocksize(blocksize)
-
+    
+def set_releasegil( gilstate ):
+    """
+    set_releasegil( gitstate )
+    
+    Sets a boolean on whether to release the Python global inter-lock (GIL) 
+    during c-blosc compress and decompress operations or not.  This defaults 
+    to False.
+    
+    Notes
+    -----
+    
+    Designed to be used with larger chunk sizes and a ThreadPool.  There is a 
+    small performance penalty with releasing the GIL that will more harshly 
+    penalize small block sizes.
+    
+    Examples
+    --------
+    
+    >>> oldReleaseState = blosc.set_releasegil(True)
+    
+    """
+    gilstate = bool(gilstate)
+    return _ext.set_releasegil( gilstate )
 
 def compressor_list():
     """
@@ -303,10 +326,10 @@ def compress(bytesobj, typesize=8, clevel=9, shuffle=blosc.SHUFFLE,
         blosc.NOSHUFFLE, blosc.SHUFFLE and blosc.BITSHUFFLE.  The
         default is blosc.SHUFFLE.
     cname : string (optional)
-        The name of the compressor used internally in Blosc.
-        It can be any of the supported by Blosc ('blosclz',
-        'lz4', 'lz4hc', 'snappy', 'zlib' and maybe others too).
-        The default is 'blosclz'.
+        The name of the compressor used internally in Blosc. It can be
+        any of the supported by Blosc ('blosclz', 'lz4', 'lz4hc',
+        'snappy', 'zlib', 'zstd' and maybe others too). The default is
+        'blosclz'.
 
     Returns
     -------
@@ -366,10 +389,10 @@ def compress_ptr(address, items, typesize=8, clevel=9, shuffle=blosc.SHUFFLE,
         blosc.NOSHUFFLE, blosc.SHUFFLE and blosc.BITSHUFFLE.  The
         default is blosc.SHUFFLE.
     cname : string (optional)
-        The name of the compressor used internally in Blosc.
-        It can be any of the supported by Blosc ('blosclz',
-        'lz4', 'lz4hc', 'snappy', 'zlib' and maybe others too).
-        The default is 'blosclz'.
+        The name of the compressor used internally in Blosc. It can be
+        any of the supported by Blosc ('blosclz', 'lz4', 'lz4hc',
+        'snappy', 'zlib', 'zstd' and maybe others too). The default is
+        'blosclz'.
 
     Returns
     -------
@@ -575,10 +598,10 @@ def pack_array(array, clevel=9, shuffle=blosc.SHUFFLE, cname='blosclz'):
         blosc.NOSHUFFLE, blosc.SHUFFLE and blosc.BITSHUFFLE.  The
         default is blosc.SHUFFLE.
     cname : string (optional)
-        The name of the compressor used internally in Blosc.
-        It can be any of the supported by Blosc ('blosclz',
-        'lz4', 'lz4hc', 'snappy', 'zlib' and maybe others too).
-        The default is 'blosclz'.
+        The name of the compressor used internally in Blosc. It can be
+        any of the supported by Blosc ('blosclz', 'lz4', 'lz4hc',
+        'snappy', 'zlib', 'zstd' and maybe others too). The default is
+        'blosclz'.
 
     Returns
     -------
